@@ -439,16 +439,3 @@ class TestTimestreamLoader_UnitTests:
         dt = datetime.combine(date(2021, 1, 1), datetime.min.time()).replace(tzinfo=pytz.UTC)
         assert loader._TimestreamLoader__dt_to_ms(dt) == 1609459200000
         assert loader._TimestreamLoader__dt_to_ms(None) == -1
-
-    @pytest.mark.unit
-    def test_get_logger(self):
-        mock_session = MockApi()
-        mock_session.on('client', 'timestream-write', config=DEFAULT_CLIENT_CONFIG).return_val(None)
-        loader = TimestreamLoader('test', 'test', mock_session)
-        mock_session.assert_expectations()
-
-        loader._get_logger('debug')
-        loader._get_logger('warning')
-        loader._get_logger('error')
-        loader._get_logger('critical')
-        loader._get_logger('info')
