@@ -1,11 +1,11 @@
 import boto3
 import logging
 import pytz
-import sys
 
 from botocore.config import Config
 from botocore.exceptions import ClientError
 from datetime import datetime
+from timestream import DEFAULT_LOGGER, log_it
 from timestream.dimensions import TimestreamDimensions
 from timestream.load_result import TimestreamLoadResult
 from timestream.record import RejectedTimestreamRecord, TimestreamRecord
@@ -32,16 +32,17 @@ class TimestreamLoader:
         assert table_name, 'Must specify table_name'
         self.__database_name = database_name
         self.__table_name = table_name
-        self.__logger = logger if logger else self._get_logger()
         self.__session = session if session else boto3.Session()
         self.__timestream_write_client = self.__session.client('timestream-write', config=DEFAULT_CLIENT_CONFIG)
+        self._logger = logger or DEFAULT_LOGGER
 
         self.__current_time_ms = self.__dt_to_ms(datetime.now().astimezone().astimezone(pytz.utc))
         if current_time_ms is not None:
             assert type(current_time_ms) is int and current_time_ms > 0, f'Invalid current_time_ms: {current_time_ms}. Expecting an integer greater than 0'
-            self.__logger.warning(f'Overriding TimestreamLoader.__current_time_ms with value {current_time_ms}')
+            self._logger.warning(f'Overriding TimestreamLoader.__current_time_ms with value {current_time_ms}')
             self.__current_time_ms = current_time_ms
 
+    @log_it
     def load(
         self,
         data: list,
@@ -56,6 +57,7 @@ class TimestreamLoader:
         '''
         return self.__load(data, capture_time, source, upsert, ignore_parse_error, False).to_dict()
 
+    @log_it
     def load_preview(
         self,
         data: list,
@@ -71,6 +73,7 @@ class TimestreamLoader:
         '''
         return self.__load(data, capture_time, source, upsert, ignore_parse_error, True).to_dict()
 
+    @log_it
     def __load(
         self,
         data: list,
@@ -114,6 +117,7 @@ class TimestreamLoader:
                 result.error = Exception('Some records were rejected by Timestream')
         return result
 
+    @log_it
     def __write_insert_records(
         self,
         dimensions: TimestreamDimensions,
@@ -136,10 +140,11 @@ class TimestreamLoader:
                 Records=[r.loadable() for r in records]
             )
         except ClientError as e:
-            self.__logger.error(f'Failed to write insert records: {e}')
+            self._logger.error(f'Failed to write insert records: {e}')
             accepted_records, rejected_records = self.__process_client_error(e, records)
         return accepted_records, rejected_records
 
+    @log_it
     def __write_upsert_records(
         self,
         dimensions: TimestreamDimensions,
@@ -158,10 +163,11 @@ class TimestreamLoader:
                 Records=[r.loadable() for r in records]
             )
         except ClientError as e:
-            self.__logger.error(f'Failed to write upsert records: {e}')
+            self._logger.error(f'Failed to write upsert records: {e}')
             accepted_records, rejected_records = self.__process_client_error(e, records)
         return accepted_records, rejected_records
 
+    @log_it
     def __process_client_error(self, e: ClientError, records: List[TimestreamRecord]) -> tuple:
         '''
         Processes a boto ClientError from a Timestream write operation. Logs error messages
@@ -175,7 +181,7 @@ class TimestreamLoader:
                 record=records[rejection_data['RecordIndex']],
                 error=Exception(rejection_data['Reason'])
             )
-            self.__logger.error(f'Rejected record:\n{rejected_record}')
+            self._logger.error(f'Rejected record:\n{rejected_record}')
             rejected_records.append(rejected_record) 
             rejected_indices.append(rejection_data['RecordIndex'])
         
@@ -185,6 +191,7 @@ class TimestreamLoader:
         ]
         return accepted_records, rejected_records
 
+    @log_it
     def __parse_data(self, data: List[dict], upsert: bool, ignore_parse_error: bool) -> TimestreamLoadResult:
         '''
         Parses the given data and returns a TimestreamLoadResult that contains:
@@ -206,6 +213,7 @@ class TimestreamLoader:
             result.add_accepted_records(records_from_item)
         return result
 
+    @log_it
     def __parse_item(self, item: dict, upsert: bool, ignore_parse_error: bool) -> List[TimestreamRecord]:
         '''
         Parses a single dictionary into Timestream records. A single dictionary may break down into
@@ -252,7 +260,7 @@ class TimestreamLoader:
                 msg = f'Could not create a record or dimension from type "{type(v)}" at key {k}'
                 if not ignore_parse_error:
                     raise AssertionError(msg)
-                self.__logger.warning(msg)
+                self._logger.warning(msg)
 
         # Recreate all records with dimensions attached and return
         return [
@@ -270,31 +278,3 @@ class TimestreamLoader:
         if dt:
             return int(round(dt.timestamp() * 1000))
         return -1
-
-    def _get_logger(self, log_level: str = 'info') -> logging.Logger:
-        """Return a logger with the given logging level set"""
-        handler = logging.StreamHandler(sys.stdout)
-        log = logging.getLogger('prometheus_exporter')
-        log_level = log_level.lower()
-        if log_level == 'debug':
-            log.setLevel(logging.DEBUG)
-            handler.setLevel(logging.DEBUG)
-        elif log_level == 'warning':
-            log.setLevel(logging.WARNING)
-            handler.setLevel(logging.WARNING)
-        elif log_level == 'error':
-            log.setLevel(logging.ERROR)
-            handler.setLevel(logging.ERROR)
-        elif log_level == 'critical':
-            log.setLevel(logging.CRITICAL)
-            handler.setLevel(logging.CRITICAL)
-        else:
-            log.setLevel(logging.INFO)
-            handler.setLevel(logging.INFO)
-
-        formatter = logging.Formatter(
-            '%(asctime)s [%(levelname)s] %(filename)s:%(lineno)d - %(message)s')
-        handler.setFormatter(formatter)
-        log.addHandler(handler)
-        log.propagate = False
-        return log
